@@ -13,6 +13,7 @@ from .exchange_rate import ExchangeRate as _er
 from .cash_advances import CashAdvances as _cash_advances
 from .reports import Reports as _reports
 from .filings import Filings as _filings
+from .payments import Payments as _payments
 from .api import AuthenticationError, PermissionsError, ResourceNotFound, TooManyRequests, ApiError
 from datetime import datetime
 
@@ -32,6 +33,7 @@ class ListoApi():
         self.CashAdvances = _cash_advances(token, base_url)
         self.Filings = _filings(token, base_url)
         self.Reports = _reports(token, base_url)
+        self.Payments = _payments(token, base_url)
         if is_vault:
             self.InvoicingVault = _invoicing_vault(token, base_url, certificate_num, cer_path)
         if cer_path and key_path and key_passphrase:
