@@ -61,22 +61,16 @@ class Banks(ListoAPI):
             def _request(kwargs):
                 return self.make_request(method="GET", path="/banks/" + str(rfc_id) + "/transactions/" + str(reconciliation_id) + "/reconciliation/info")
 
-            kwargs.setdefault("offset", 0)
-            size = kwargs.setdefault("size", 250)
+            try:
+                r = _request(kwargs)
+            except TooManyRequests:
+                sleep(sleep_length)
+                r = _request(kwargs)
 
-            while True:
-                try:
-                    r = _request(kwargs)
-                except TooManyRequests:
-                    sleep(sleep_length)
-                    r = _request(kwargs)
-
-                r = r.json()
-                if not r:
-                    break
-                for i in r:
-                    yield i
-                kwargs["offset"] += size
+            if r.status_code == 200:
+                return r.json()
+            else:
+                return {"error": r.text, "code": r.status_code}
 
         except WrongDataFormat:
-             pass
+            pass
