@@ -149,7 +149,19 @@ class InvoicingVault(InvoicingMixin):
             else:
                 yield {}, certification_data, original_chain
 
-    def cancel(self, gid, rfc):
+    def cancel(self, invoice_id, rfc, cfdi_kind="invoice", reason=None, substituted_by_uuid=None):
+        """Cancel Invoice
+        Args:
+            invoice_id (str or int): invoice.id
+            cfdi_kind (str): Kind of CFDI to cancel. invoice or withholding (Optional)
+            rfc (str): Issuer RFC
+            reason (str: optional):
+                “01” Comprobantes emitidos con errores con relación.
+                “02” Comprobantes emitidos con errores sin relación.
+                “03” No se llevó a cabo la operación.
+                “04” Operación nominativa relacionada en una factura global.
+            substituted_by_uuid (str: optional-conditional): New invoice's UUID which replace the current CFDI
+        """
         # Validate data
         self.validate_rfc(rfc)
 
@@ -165,9 +177,11 @@ class InvoicingVault(InvoicingMixin):
         data = {
             'rfc_id': self.rfc_id,
             'key_id': self.key_id,
-            'message': base64.b64encode(self.cert_der).decode("utf-8")
+            'message': base64.b64encode(self.cert_der).decode("utf-8"),
+            "reason": reason,
+            "substituted_by_uuid": substituted_by_uuid
         }
-        return self.make_request(method="POST", json=data, path="/invoicing/cancel_using_vault_private_key/invoice/{}/".format(gid)).json()
+        return self.make_request(method="POST", json=data, path=f"/invoicing/cancel_using_vault_private_key/{cfdi_kind}/{invoice_id}/").json()
 
 class Invoicing(InvoicingMixin):
     """Invoicing class
@@ -208,15 +222,23 @@ class Invoicing(InvoicingMixin):
         private_pem = proc.communicate(input=self.private_key_der)[0].strip()
         self.key = crypto.load_privatekey(crypto.FILETYPE_PEM, private_pem)
 
-    def cancel(self, gid):
+    def cancel(self, gid, reason=None, substituted_by_uuid=None):
         """Cancel Invoice
         Args:
             gid: invoice.generated_invoice_id, do not mistake with invoice.id
+            reason (str: optional):
+                “01” Comprobantes emitidos con errores con relación.
+                “02” Comprobantes emitidos con errores sin relación.
+                “03” No se llevó a cabo la operación.
+                “04” Operación nominativa relacionada en una factura global.
+            substituted_by_uuid (str: optional-conditional): New invoice's UUID which replace the current CFDI
         """
         cd = {
             "certificate_der": base64.b64encode(self.cert_der).decode("utf-8"),
             "passcode": self.PRIVATE_KEY_PASSPHRASE,
             "private_key_der": base64.b64encode(self.private_key_der).decode("utf-8"),
+            "reason": reason,
+            "substituted_by_uuid": substituted_by_uuid
         }
         return self._cancel(cd, "/invoicing/cancel/invoice/{}/".format(gid)).json()
 
